@@ -5,15 +5,14 @@ With this module, you will be able to send GraphQL and REST queries
 to GitHub, as well as read and write JSON files to store data.
 """
 
+from datetime import datetime
 import json
 import os
 import re
 import time
 
-from datetime import datetime
-from subprocess import check_output, DEVNULL  # nosec
-
 import pytz
+import requests
 
 
 def _vPrint(verbose, *args, **kwargs):
@@ -26,9 +25,7 @@ def _vPrint(verbose, *args, **kwargs):
 
     """
     if verbose:
-        return print(*args, **kwargs)
-    else:
-        pass
+        print(*args, **kwargs)
 
 
 class GitHubQueryManager:
@@ -58,18 +55,23 @@ class GitHubQueryManager:
             self.__githubApiToken = apiToken
         else:
             try:
-                self.__githubApiToken = os.environ['GITHUB_API_TOKEN']
+                self.__githubApiToken = os.environ["GITHUB_API_TOKEN"]
             except KeyError as error:
-                raise TypeError("Requires either a string argument or environment variable 'GITHUB_API_TOKEN'.") from error
+                raise TypeError(
+                    "Requires either a string argument or environment variable 'GITHUB_API_TOKEN'."
+                ) from error
 
         # Check token validity
         print("Checking GitHub API token... ", end="", flush=True)
-        basicCheck = self._submitQuery('query { viewer { login } }')
+        basicCheck = self._submitQuery("query { viewer { login } }")
         if basicCheck["statusNum"] == 401:
             print("FAILED.")
-            raise ValueError("GitHub API token is not valid.\n" + basicCheck["headDict"]["http"] + " " + basicCheck["result"])
-        else:
-            print("Token validated.")
+            raise ValueError(
+                "GitHub API token is not valid.\n%s %s"
+                % (basicCheck["statusTxt"], basicCheck["result"])
+            )
+
+        print("Token validated.")
 
         # Initialize private variables
         self.__retryDelay = 3  #: Number of seconds to wait between retries.
@@ -93,8 +95,7 @@ class GitHubQueryManager:
     @maxRetry.setter
     def maxRetry(self, maxRetry):
         numIn = int(maxRetry)
-        if not numIn > 0:
-            numIn = 1
+        numIn = 1 if numIn <= 0 else numIn
         self.__maxRetry = numIn
         print("Auto-retry limit for requests set to %d." % (self.maxRetry))
 
@@ -121,24 +122,27 @@ class GitHubQueryManager:
         lastModified = os.path.getmtime(filePath)
         absPath = os.path.abspath(filePath)
         if absPath == self.__queryPath and lastModified == self.__queryTimestamp:
-            _vPrint(verbose, "Using cached query '%s'" % (os.path.basename(self.__queryPath)))
+            _vPrint(
+                verbose,
+                "Using cached query '%s'" % (os.path.basename(self.__queryPath)),
+            )
             query_in = self.__query
         else:
             _vPrint(verbose, "Reading '%s' ... " % (filePath), end="", flush=True)
-            with open(filePath, "r") as q:
-                # Strip all comments and newlines.
-                query_in = re.sub(r'#.*(\n|\Z)', '\n', q.read())
-                # Condense extra whitespace.
-                query_in = re.sub(r'\s+', ' ', query_in)
-                # Remove any leading or trailing whitespace.
-                query_in = re.sub(r'(\A\s+)|(\s+\Z)', '', query_in)
+            with open(filePath, "r", encoding="utf-8") as q:
+                # Strip comments.
+                query_in = re.sub(r"#.*(\n|\Z)", "\n", q.read())
+                # Condense whitespace.
+                query_in = re.sub(r"\s+", " ", query_in)
+                # Remove leading and trailing whitespace.
+                query_in = query_in.strip()
             _vPrint(verbose, "File read!")
             self.__queryPath = absPath
             self.__queryTimestamp = lastModified
             self.__query = query_in
         return query_in
 
-    def queryGitHubFromFile(self, filePath, gitvars={}, verbosity=0, **kwargs):
+    def queryGitHubFromFile(self, filePath, gitvars=None, verbosity=0, **kwargs):
         """Submit a GitHub GraphQL query from a file.
 
         Can only be used with GraphQL queries.
@@ -151,7 +155,7 @@ class GitHubQueryManager:
                 .. _GitHub GraphQL Explorer:
                    https://developer.github.com/v4/explorer/
             gitvars (Optional[Dict]): All query variables.
-                Defaults to empty.
+                Defaults to None.
                 GraphQL Only.
             verbosity (Optional[int]): Changes output verbosity levels.
                 If < 0, all extra printouts are suppressed.
@@ -164,10 +168,27 @@ class GitHubQueryManager:
             Dict: A JSON style dictionary.
 
         """
-        gitquery = self._readGQL(filePath, verbose=(verbosity >= 0))
-        return self.queryGitHub(gitquery, gitvars=gitvars, verbosity=verbosity, **kwargs)
+        if not gitvars:
+            gitvars = {}
 
-    def queryGitHub(self, gitquery, gitvars={}, verbosity=0, paginate=False, cursorVar=None, keysToList=[], rest=False, requestCount=0, pageNum=0):
+        gitquery = self._readGQL(filePath, verbose=(verbosity >= 0))
+        return self.queryGitHub(
+            gitquery, gitvars=gitvars, verbosity=verbosity, **kwargs
+        )
+
+    def queryGitHub(
+        self,
+        gitquery,
+        gitvars=None,
+        verbosity=0,
+        paginate=False,
+        cursorVar=None,
+        keysToList=None,
+        rest=False,
+        requestCount=0,
+        pageNum=0,
+        headers=None,
+    ):
         """Submit a GitHub query.
 
         Args:
@@ -176,7 +197,7 @@ class GitHubQueryManager:
                        query: 'query { viewer { login } }'
                     endpoint: '/user'
             gitvars (Optional[Dict]): All query variables.
-                Defaults to empty.
+                Defaults to None.
                 GraphQL Only.
             verbosity (Optional[int]): Changes output verbosity levels.
                 If < 0, all extra printouts are suppressed.
@@ -190,7 +211,7 @@ class GitHubQueryManager:
                 GraphQL Only.
             keysToList (Optional[List[str]]): Ordered list of keys needed to
                 retrieve the list in the query results to be extended by
-                pagination. Defaults to empty.
+                pagination. Defaults to None.
                 Example:
                     ['data', 'viewer', 'repositories', 'nodes']
                 GraphQL Only.
@@ -199,22 +220,38 @@ class GitHubQueryManager:
             requestCount (Optional[int]): Counter for repeated requests.
             pageNum (Optional[int]): Counter for pagination.
                 For user readable log messages only, does not affect data.
+            headers (Optional[Dict]): Additional headers.
+                Defaults to None.
 
         Returns:
             Dict: A JSON style dictionary.
 
         """
+        if not gitvars:
+            gitvars = {}
+        if not keysToList:
+            keysToList = []
+        if not headers:
+            headers = {}
+
         requestCount += 1
-        if pageNum < 0:  # no negative page numbers
-            pageNum = 0
+        pageNum = 0 if pageNum < 0 else pageNum  # no negative page numbers
         pageNum += 1
 
         if paginate:
             _vPrint((verbosity >= 0), "Page %d" % (pageNum))
-        _vPrint((verbosity >= 0), "Sending %s query..." % ("REST" if rest else "GraphQL"))
-        response = self._submitQuery(gitquery, gitvars=gitvars, verbose=(verbosity > 0), rest=rest)
+        _vPrint(
+            (verbosity >= 0), "Sending %s query..." % ("REST" if rest else "GraphQL")
+        )
+        response = self._submitQuery(
+            gitquery,
+            gitvars=gitvars,
+            verbose=(verbosity > 0),
+            rest=rest,
+            headers=headers,
+        )
         _vPrint((verbosity >= 0), "Checking response...")
-        _vPrint((verbosity >= 0), response["headDict"]["http"])
+        _vPrint((verbosity >= 0), "HTTP STATUS %s" % (response["statusTxt"]))
         statusNum = response["statusNum"]
 
         # Decrement page count before error checks to properly reflect any repeated queries
@@ -225,14 +262,25 @@ class GitHubQueryManager:
             apiStatus = {
                 "limit": int(response["headDict"]["X-RateLimit-Limit"]),
                 "remaining": int(response["headDict"]["X-RateLimit-Remaining"]),
-                "reset": int(response["headDict"]["X-RateLimit-Reset"])
+                "reset": int(response["headDict"]["X-RateLimit-Reset"]),
             }
             _vPrint((verbosity >= 0), "API Status %s" % (json.dumps(apiStatus)))
-            if not apiStatus["remaining"] > 0:
+            if apiStatus["remaining"] <= 0:
                 _vPrint((verbosity >= 0), "API usage limit reached during query.")
                 self._awaitReset(apiStatus["reset"])
                 _vPrint((verbosity >= 0), "Repeating query...")
-                return self.queryGitHub(gitquery, gitvars=gitvars, verbosity=verbosity, paginate=paginate, cursorVar=cursorVar, keysToList=keysToList, rest=rest, requestCount=(requestCount - 1), pageNum=pageNum)
+                return self.queryGitHub(
+                    gitquery,
+                    gitvars=gitvars,
+                    verbosity=verbosity,
+                    paginate=paginate,
+                    cursorVar=cursorVar,
+                    keysToList=keysToList,
+                    rest=rest,
+                    requestCount=(requestCount - 1),
+                    pageNum=pageNum,
+                    headers=headers,
+                )
         except KeyError:
             # Handles error cases that don't return X-RateLimit data
             _vPrint((verbosity >= 0), "Failed to check API Status.")
@@ -240,20 +288,67 @@ class GitHubQueryManager:
         # Check for accepted but not yet processed, usually due to un-cached data
         if statusNum == 202:
             if requestCount >= self.maxRetry:
-                raise RuntimeError("Query attempted but failed %d times.\n%s\n%s" % (self.maxRetry, response["headDict"]["http"], response["result"]))
-            else:
-                self._countdown(self.__retryDelay, printString="Query accepted but not yet processed. Trying again in %*dsec...", verbose=(verbosity >= 0))
-                return self.queryGitHub(gitquery, gitvars=gitvars, verbosity=verbosity, paginate=paginate, cursorVar=cursorVar, keysToList=keysToList, rest=rest, requestCount=requestCount, pageNum=pageNum)
+                raise RuntimeError(
+                    "Query attempted but failed %d times.\n%s\n%s"
+                    % (
+                        self.maxRetry,
+                        response["statusTxt"],
+                        response["result"],
+                    )
+                )
+
+            self._countdown(
+                self.__retryDelay,
+                printString="Query accepted but not yet processed. Trying again in %*dsec...",
+                verbose=(verbosity >= 0),
+            )
+            return self.queryGitHub(
+                gitquery,
+                gitvars=gitvars,
+                verbosity=verbosity,
+                paginate=paginate,
+                cursorVar=cursorVar,
+                keysToList=keysToList,
+                rest=rest,
+                requestCount=requestCount,
+                pageNum=pageNum,
+                headers=headers,
+            )
         # Check for server error responses
-        if statusNum == 502 or statusNum == 503:
+        if statusNum in (502, 503):
             if requestCount >= self.maxRetry:
-                raise RuntimeError("Query attempted but failed %d times.\n%s\n%s" % (self.maxRetry, response["headDict"]["http"], response["result"]))
-            else:
-                self._countdown(self.__retryDelay, printString="Server error. Trying again in %*dsec...", verbose=(verbosity >= 0))
-                return self.queryGitHub(gitquery, gitvars=gitvars, verbosity=verbosity, paginate=paginate, cursorVar=cursorVar, keysToList=keysToList, rest=rest, requestCount=requestCount, pageNum=pageNum)
+                raise RuntimeError(
+                    "Query attempted but failed %d times.\n%s\n%s"
+                    % (
+                        self.maxRetry,
+                        response["statusTxt"],
+                        response["result"],
+                    )
+                )
+
+            self._countdown(
+                self.__retryDelay,
+                printString="Server error. Trying again in %*dsec...",
+                verbose=(verbosity >= 0),
+            )
+            return self.queryGitHub(
+                gitquery,
+                gitvars=gitvars,
+                verbosity=verbosity,
+                paginate=paginate,
+                cursorVar=cursorVar,
+                keysToList=keysToList,
+                rest=rest,
+                requestCount=requestCount,
+                pageNum=pageNum,
+                headers=headers,
+            )
         # Check for other error responses
         if statusNum >= 400 or statusNum == 204:
-            raise RuntimeError("Request got an Error response.\n%s\n%s" % (response["headDict"]["http"], response["result"]))
+            raise RuntimeError(
+                "Request got an Error response.\n%s\n%s"
+                % (response["statusTxt"], response["result"])
+            )
 
         _vPrint((verbosity >= 0), "Data received!")
         outObj = json.loads(response["result"])
@@ -261,14 +356,42 @@ class GitHubQueryManager:
         # Check for GraphQL API errors (e.g. repo not found)
         if not rest and "errors" in outObj:
             if requestCount >= self.maxRetry:
-                raise RuntimeError("Query attempted but failed %d times.\n%s\n%s" % (self.maxRetry, response["headDict"]["http"], response["result"]))
-            elif len(outObj["errors"]) == 1 and len(outObj["errors"][0]) == 1:
+                raise RuntimeError(
+                    "Query attempted but failed %d times.\n%s\n%s"
+                    % (
+                        self.maxRetry,
+                        response["statusTxt"],
+                        response["result"],
+                    )
+                )
+
+            if len(outObj["errors"]) == 1 and len(outObj["errors"][0]) == 1:
                 # Poorly defined error type, usually intermittent, try again.
-                _vPrint((verbosity >= 0), "GraphQL API error.\n%s" % (json.dumps(outObj["errors"])))
-                self._countdown(self.__retryDelay, printString="Unknown API error. Trying again in %*dsec...", verbose=(verbosity >= 0))
-                return self.queryGitHub(gitquery, gitvars=gitvars, verbosity=verbosity, paginate=paginate, cursorVar=cursorVar, keysToList=keysToList, rest=rest, requestCount=requestCount, pageNum=pageNum)
-            else:
-                raise RuntimeError("GraphQL API error.\n%s" % (json.dumps(outObj["errors"])))
+                _vPrint(
+                    (verbosity >= 0),
+                    "GraphQL API error.\n%s" % (json.dumps(outObj["errors"])),
+                )
+                self._countdown(
+                    self.__retryDelay,
+                    printString="Unknown API error. Trying again in %*dsec...",
+                    verbose=(verbosity >= 0),
+                )
+                return self.queryGitHub(
+                    gitquery,
+                    gitvars=gitvars,
+                    verbosity=verbosity,
+                    paginate=paginate,
+                    cursorVar=cursorVar,
+                    keysToList=keysToList,
+                    rest=rest,
+                    requestCount=requestCount,
+                    pageNum=pageNum,
+                    headers=headers,
+                )
+
+            raise RuntimeError(
+                "GraphQL API error.\n%s" % (json.dumps(outObj["errors"]))
+            )
 
         # Re-increment page count before the next page query
         pageNum += 1
@@ -277,19 +400,45 @@ class GitHubQueryManager:
         if paginate:
             if rest and response["linkDict"]:
                 if "next" in response["linkDict"]:
-                    nextObj = self.queryGitHub(response["linkDict"]["next"], gitvars=gitvars, verbosity=verbosity, paginate=paginate, cursorVar=cursorVar, keysToList=keysToList, rest=rest, requestCount=0, pageNum=pageNum)
+                    nextObj = self.queryGitHub(
+                        response["linkDict"]["next"],
+                        gitvars=gitvars,
+                        verbosity=verbosity,
+                        paginate=paginate,
+                        cursorVar=cursorVar,
+                        keysToList=keysToList,
+                        rest=rest,
+                        requestCount=0,
+                        pageNum=pageNum,
+                        headers=headers,
+                    )
                     outObj.extend(nextObj)
             elif not rest:
                 if not cursorVar:
-                    raise ValueError("Must specify argument 'cursorVar' to use GraphQL auto-pagination.")
+                    raise ValueError(
+                        "Must specify argument 'cursorVar' to use GraphQL auto-pagination."
+                    )
                 if not len(keysToList) > 0:
-                    raise ValueError("Must specify argument 'keysToList' as a non-empty list to use GraphQL auto-pagination.")
+                    raise ValueError(
+                        "Must specify argument 'keysToList' as a non-empty list to use GraphQL auto-pagination."
+                    )
                 aPage = outObj
                 for key in keysToList[0:-1]:
                     aPage = aPage[key]
                 gitvars[cursorVar] = aPage["pageInfo"]["endCursor"]
                 if aPage["pageInfo"]["hasNextPage"]:
-                    nextObj = self.queryGitHub(gitquery, gitvars=gitvars, verbosity=verbosity, paginate=paginate, cursorVar=cursorVar, keysToList=keysToList, rest=rest, requestCount=0, pageNum=pageNum)
+                    nextObj = self.queryGitHub(
+                        gitquery,
+                        gitvars=gitvars,
+                        verbosity=verbosity,
+                        paginate=paginate,
+                        cursorVar=cursorVar,
+                        keysToList=keysToList,
+                        rest=rest,
+                        requestCount=0,
+                        pageNum=pageNum,
+                        headers=headers,
+                    )
                     newPage = nextObj
                     for key in keysToList[0:-1]:
                         newPage = newPage[key]
@@ -298,7 +447,9 @@ class GitHubQueryManager:
 
         return outObj
 
-    def _submitQuery(self, gitquery, gitvars={}, verbose=False, rest=False):
+    def _submitQuery(
+        self, gitquery, gitvars=None, verbose=False, rest=False, headers=None
+    ):
         """Send a curl request to GitHub.
 
         Args:
@@ -307,61 +458,70 @@ class GitHubQueryManager:
                        query: 'query { viewer { login } }'
                     endpoint: '/user'
             gitvars (Optional[Dict]): All query variables.
-                Defaults to empty.
+                Defaults to None.
             verbose (Optional[bool]): If False, stderr prints will be
                 suppressed. Defaults to False.
             rest (Optional[bool]): If True, uses the REST API instead
                 of GraphQL. Defaults to False.
+            headers (Optional[Dict]): Additional headers.
+                Defaults to None.
 
         Returns:
             {
                 'statusNum' (int): The HTTP status code.
+                'statusTxt' (str): The HTTP status message.
                 'headDict' (Dict[str]): The response headers.
                 'linkDict' (Dict[int]): Link based pagination data.
                 'result' (str): The body of the response.
             }
 
         """
-        errOut = DEVNULL if not verbose else None
-        authhead = 'Authorization: bearer ' + self.__githubApiToken
+        if not gitvars:
+            gitvars = {}
+        if not headers:
+            headers = {}
 
-        bashcurl = 'curl -iH TMPauthhead -X POST -d TMPgitquery https://api.github.com/graphql' if not rest \
-            else 'curl -iH TMPauthhead https://api.github.com' + gitquery
-        bashcurl_list = bashcurl.split()
-        bashcurl_list[2] = authhead
+        authhead = {"Authorization": "bearer " + self.__githubApiToken}
         if not rest:
-            gitqueryJSON = json.dumps({'query': gitquery, 'variables': json.dumps(gitvars)})
-            bashcurl_list[6] = gitqueryJSON
-
-        fullResponse = check_output(bashcurl_list, stderr=errOut).decode()
-        _vPrint(verbose, "\n" + fullResponse)
-        fullResponse = fullResponse.split('\r\n\r\n')
-        heads = fullResponse[0].split('\r\n')
-        if len(fullResponse) > 1:
-            result = fullResponse[1]
+            gitqueryJSON = json.dumps(
+                {"query": gitquery, "variables": json.dumps(gitvars)}
+            )
+            fullResponse = requests.post(
+                "https://api.github.com/graphql",
+                data=gitqueryJSON,
+                headers={**authhead, **headers},
+            )
         else:
-            result = ""
-        http = heads[0].split()
-        statusNum = int(http[1])
-
-        # Parse headers into a useful dictionary
-        headDict = {}
-        headDict["http"] = heads[0]
-        for header in heads[1:]:
-            h = header.split(': ')
-            headDict[h[0]] = h[1]
+            fullResponse = requests.get(
+                "https://api.github.com" + gitquery, headers={**authhead, **headers}
+            )
+        _vPrint(
+            verbose,
+            "\n%s\n%s"
+            % (json.dumps(dict(fullResponse.headers), indent=2), fullResponse.text),
+        )
+        result = fullResponse.text
+        headDict = fullResponse.headers
+        statusNum = int(fullResponse.status_code)
+        statusTxt = "%d %s" % (statusNum, fullResponse.reason)
 
         # Parse any Link headers even further
         linkDict = None
         if "Link" in headDict:
-            linkProperties = headDict["Link"].split(', ')
+            linkProperties = headDict["Link"].split(", ")
             propDict = {}
             for item in linkProperties:
                 divided = re.split(r'<https://api.github.com|>; rel="|"', item)
                 propDict[divided[2]] = divided[1]
             linkDict = propDict
 
-        return {'statusNum': statusNum, 'headDict': headDict, 'linkDict': linkDict, 'result': result}
+        return {
+            "statusNum": statusNum,
+            "statusTxt": statusTxt,
+            "headDict": headDict,
+            "linkDict": linkDict,
+            "result": result,
+        }
 
     def _awaitReset(self, utcTimeStamp, verbose=True):
         """Wait until the given UTC timestamp.
@@ -374,17 +534,21 @@ class GitHubQueryManager:
         """
         resetTime = pytz.utc.localize(datetime.utcfromtimestamp(utcTimeStamp))
         _vPrint(verbose, "--- Current Timestamp")
-        _vPrint(verbose, "      %s" % (time.strftime('%c')))
+        _vPrint(verbose, "      %s" % (time.strftime("%c")))
         now = pytz.utc.localize(datetime.utcnow())
         waitTime = round((resetTime - now).total_seconds()) + 1
         _vPrint(verbose, "--- Current UTC Timestamp")
-        _vPrint(verbose, "      %s" % (now.strftime('%c')))
+        _vPrint(verbose, "      %s" % (now.strftime("%c")))
         _vPrint(verbose, "--- GITHUB NEEDS A BREAK Until UTC Timestamp")
-        _vPrint(verbose, "      %s" % (resetTime.strftime('%c')))
-        self._countdown(waitTime, printString="--- Waiting %*d seconds...", verbose=verbose)
+        _vPrint(verbose, "      %s" % (resetTime.strftime("%c")))
+        self._countdown(
+            waitTime, printString="--- Waiting %*d seconds...", verbose=verbose
+        )
         _vPrint(verbose, "--- READY!")
 
-    def _countdown(self, waitTime=0, printString="Waiting %*d seconds...", verbose=True):
+    def _countdown(
+        self, waitTime=0, printString="Waiting %*d seconds...", verbose=True
+    ):
         """Makes a pretty countdown.
 
         Args:
@@ -401,7 +565,12 @@ class GitHubQueryManager:
         if waitTime <= 0:
             waitTime = self.__retryDelay
         for remaining in range(waitTime, 0, -1):
-            _vPrint(verbose, "\r" + printString % (len(str(waitTime)), remaining), end="", flush=True)
+            _vPrint(
+                verbose,
+                "\r" + printString % (len(str(waitTime)), remaining),
+                end="",
+                flush=True,
+            )
             time.sleep(1)
         if verbose:
             _vPrint(verbose, "\r" + printString % (len(str(waitTime)), 0))
@@ -440,7 +609,10 @@ class DataManager:
     def filePath(self, filePath):
         if filePath:
             if not os.path.isfile(filePath):
-                print("Data file '%s' does not currently exist. Saving data will create a new file." % (filePath))
+                print(
+                    "Data file '%s' does not currently exist. Saving data will create a new file."
+                    % (filePath)
+                )
             self.__filePath = os.path.abspath(filePath)
             print("Stored new data file path '%s'" % (self.filePath))
         else:
@@ -468,16 +640,20 @@ class DataManager:
             filePath = self.filePath
         if not os.path.isfile(filePath):
             raise FileNotFoundError("Data file '%s' does not exist." % (filePath))
-        else:
-            print("Importing existing data file '%s' ... " % (filePath), end="", flush=True)
-            with open(filePath, "r") as q:
-                data_raw = q.read()
-            print("Imported!")
-            self.data = json.loads(data_raw)
-            if updatePath:
-                self.filePath = filePath
 
-    def fileSave(self, filePath=None, updatePath=False):
+        print(
+            "Importing existing data file '%s' ... " % (filePath),
+            end="",
+            flush=True,
+        )
+        with open(filePath, "r", encoding="utf-8") as q:
+            data_raw = q.read()
+        print("Imported!")
+        self.data = json.loads(data_raw)
+        if updatePath:
+            self.filePath = filePath
+
+    def fileSave(self, filePath=None, updatePath=False, newline=None):
         """Write the internal JSON data dictionary to a JSON data file.
 
         If no file path is provided, the stored data file path will be used.
@@ -487,6 +663,8 @@ class DataManager:
                 '.json' file. Defaults to None.
             updatePath (Optional[bool]): Specifies whether or not to update
                 the stored data file path. Defaults to False.
+            newline (Optional[str]): Specifies the line endings to use when
+                writing the file. Defaults to system default line separator.
 
         """
         if not filePath:
@@ -497,7 +675,7 @@ class DataManager:
                 os.makedirs(os.path.split(filePath)[0])
         dataJsonString = json.dumps(self.data, indent=4, sort_keys=True)
         print("Writing to file '%s' ... " % (filePath), end="", flush=True)
-        with open(filePath, "w") as fileout:
+        with open(filePath, "w", encoding="utf-8", newline=newline) as fileout:
             fileout.write(dataJsonString)
         print("Wrote file!")
         if updatePath:
